@@ -2,6 +2,8 @@ package UR::Namespace::View::SchemaBrowser::CgiApp;
 
 use strict;
 use warnings;
+require UR;
+our $VERSION = $UR::VERSION;
 
 UR::Object::Type->define(
     class_name => 'UR::Namespace::View::SchemaBrowser::CgiApp',
