@@ -2,6 +2,8 @@ package UR::Object::Property::View::ReferenceDescription::Text;
 
 use strict;
 use warnings;
+require UR;
+our $VERSION = $UR::VERSION;
 
 UR::Object::Type->define(
     class_name => __PACKAGE__,
